@@ -25,7 +25,7 @@ use MIDI::Drummer::Tiny::Types qw(:all);
 use Data::Dumper::Compact      qw(ddc);
 use namespace::clean;
 
-our $VERSION = '0.6000';
+our $VERSION = '0.6001';
 
 use constant STRAIGHT => 50;    # Swing percent
 
@@ -186,7 +186,7 @@ has channel => (
     default => 9,
 );
 
-sub set_channel ( $self, $channel //= 9 ) {
+sub set_channel ( $self, $channel = 9 ) {
     $self->score->noop("c$channel");
     $self->_set_channel($channel);
     return;
@@ -325,16 +325,24 @@ for my $is ( keys %attr_defaults ) {
 #pod
 #pod =item snare, acoustic_snare, electric_snare, side_stick, clap
 #pod
+#pod =back
+#pod
 #pod Where the B<snare> is by default the same as the B<acoustic_snare> but
 #pod can be overridden with the B<electric_snare> (C<'n40'>).
 #pod
+#pod =over 4
+#pod
 #pod =item hi_tom, hi_mid_tom, low_mid_tom, low_tom, hi_floor_tom, low_floor_tom
 #pod
 #pod =item kick, acoustic_bass, electric_bass
 #pod
+#pod =back
+#pod
 #pod Where the B<kick> is by default the same as the B<acoustic_bass> but
 #pod can be overridden with the B<electric_bass> (C<'n36'>).
 #pod
+#pod =over 4
+#pod
 #pod =item tambourine, cowbell, vibraslap
 #pod
 #pod =item hi_bongo, low_bongo, mute_hi_conga, open_hi_conga, low_conga, high_timbale, low_timbale
@@ -1348,7 +1356,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.6000
+version 0.6001
 
 =head1 SYNOPSIS
 
@@ -1842,16 +1850,24 @@ See L<MIDI::Util/play_fluidsynth> for more details.
 
 =item snare, acoustic_snare, electric_snare, side_stick, clap
 
+=back
+
 Where the B<snare> is by default the same as the B<acoustic_snare> but
 can be overridden with the B<electric_snare> (C<'n40'>).
 
+=over 4
+
 =item hi_tom, hi_mid_tom, low_mid_tom, low_tom, hi_floor_tom, low_floor_tom
 
 =item kick, acoustic_bass, electric_bass
 
+=back
+
 Where the B<kick> is by default the same as the B<acoustic_bass> but
 can be overridden with the B<electric_bass> (C<'n36'>).
 
+=over 4
+
 =item tambourine, cowbell, vibraslap
 
 =item hi_bongo, low_bongo, mute_hi_conga, open_hi_conga, low_conga, high_timbale, low_timbale
@@ -1884,13 +1900,6 @@ can be overridden with the B<electric_bass> (C<'n36'>).
 
 =back
 
-=head1 THANK YOU
-
-L<Mark Gardner|https://metacpan.org/author/MJGARDNER> -
-refactoring-master - modernized everything under the hood, post-0.5013.
-
-Woo!
-
 =head1 SEE ALSO
 
 The F<t/*> test file and the F<eg/*> programs in this distribution.
@@ -1918,6 +1927,13 @@ L<https://en.wikipedia.org/wiki/General_MIDI#Percussion>
 
 L<https://en.wikipedia.org/wiki/General_MIDI_Level_2#Drum_sounds>
 
+=head1 THANK YOU
+
+L<Mark Gardner|https://metacpan.org/author/MJGARDNER> -
+refactoring-master - modernized everything under the hood, post-0.5013.
+
+Woo!
+
 =head1 AUTHOR
 
 Gene Boggs <gene.boggs@gmail.com>
